#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-applicative
version:              0.18.1.0
visibility:           public
id:                   optparse-applicative-0.18.1.0-4YkrpemfLS5AFCGvYIL2b4
key:                  optparse-applicative-0.18.1.0-4YkrpemfLS5AFCGvYIL2b4
license:              BSD-3-Clause
copyright:            (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer:           huw.campbell@gmail.com
author:               Paolo Capriotti, Huw Campbell
homepage:             https://github.com/pcapriotti/optparse-applicative
synopsis:             Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, and providing a powerful applicative
    interface for composing them.

    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash, zsh, and fish completions.

    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.

category:             System, CLI, Options, Parsing
abi:                  14ddde1a98c4080ee005111adab46713
exposed:              True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.NonEmpty
    Options.Applicative.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/optparse-applicative-0.18.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optparse-applicative-0.18.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optparse-applicative-0.18.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-applicative
hs-libraries:         HSoptparse-applicative-0.18.1.0-4YkrpemfLS5AFCGvYIL2b4
depends:
    base-4.18.2.1 prettyprinter-1.7.2-3tf524DIzfO5Juc67D70Fq
    prettyprinter-ansi-terminal-1.1.4-6oSIScOnMC45SpveRpLMe8
    process-1.6.19.0 text-2.0.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock

haddock-html:         /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

